@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.76_2'; # But I need a GP module!
+our $VERSION = '0.78_1'; # Another year in paradise
 
 # Preloaded methods go here.
 
@@ -53,13 +53,13 @@ evolutionary computation in Perl. Why would anyone want to do that
 escapes my knowledge, but, in fact, we have found it quite useful for
 our own purposes. Same as Perl itself.
 
-The design principle of Algorithm::Evolutionary is I<flexibility>: it
-should be very easy to extend using this library, and it should be
+The design principle of L<Algorithm::Evolutionary> is I<flexibility>: it
+should be very easy to create your own evolutionary algorithms using this library, and it should be
 also quite easy to program what's already there in the evolutionary
 computation community. Besides, the library classes should have
 persistence provided by XML modules, and, in some cases, YAML.
 
-The algorithm allows to create simple evolutionary algorithms, as well
+The module allows to create simple evolutionary algorithms, as well
 as more complex ones, that interface with databases or with the
 web. 
 
@@ -95,13 +95,13 @@ algorithms in general and doing them using this module in particular.</p>
 any search will return a number of papers; a journal article is
 already submitted, but meanwhile if you use it for any of your
 research, I would be very grateful if you quoted papers such as these
-(which are, of course, available under request of from your friendly
+(which are, of course, available under request or from your friendly
  university librarian):</p>
 
 =end html
 
  @article {springerlink:10.1007/s00500-009-0504-3,
-   author = {Merelo Guervs, Juan and Castillo, Pedro and Alba, Enrique},
+   author = {Merelo Guervs, Juan-Julin and Castillo, Pedro and Alba, Enrique},
    affiliation = {Universidad de Granada Depto. Arquitectura y Tecnologa de Computadores, ETS Ingenieras Informtica y Telecomunicaciones Granada Spain},
    title = {Algorithm::Evolutionary, a flexible Perl module for evolutionary computation},
    journal = {Soft Computing - A Fusion of Foundations, Methodologies and Applications},
@@ -143,7 +143,7 @@ research, I would be very grateful if you quoted papers such as these
 
 =begin html
 
-<p>or the ArXiV one linked above.</p>
+<p>or the ArXiV paper linked above.</p>
 
 <p>Some information on this paper and instructions for downloading the code used in it can
 be found in <a
@@ -152,6 +152,24 @@ group blog</a>.</p>
 
 =end html
 
+=head1 Examples
+
+There are a few examples in the C<examples> subdirectory, which should
+have been included with your CPAN bundle. For instance, check out
+C<tide_float.pl>, an example of floating point vector optimization, or
+C<cd examples; run_easy_ga.pl p_peaks.yaml>, which should run an
+    example of a
+simple GA on the P_Peaks deceptive function.
+
+Some other examples are installed: check out L<tide_bitstring.pl>,
+    L<tide_float.pl> and L<canonical-genetic-algorithm.pl>, which you
+    can run and play with to get a taste of what EA programming is
+    like, and then ammend, add and modify at leisure to create your
+    own evolutionary algorithms. For a GUI example, check
+    L<rectangle-coverage.pl>, which uses L<Tk> to show the population
+    and its evolution.
+
+
 =head1 DISCUSSION, FEATURE REQUESTS
 
 Head to the CPAN forum for this module:
@@ -173,34 +191,27 @@ who blogs at <a href='http://blojj.blogalia.com'>BloJJ</a> and
 twitters at <a
 href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
 also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
-and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
-submitted bugs include <a
-href='http://barbacana.net'>jamarier</a>, <a href='http://leandrohermida.com'>Leandro Hermida</a>, Jrme Qulin  and Mike Gajewski. <a href='http://alexm.org'>Alex Muntada</a>,
-from the <a href='http://barcelona.pm.org/'>Barcelona Perl
-Mongers</a>, helped me solve a problem with the Makefile.PL. Bug reports (and patches), requests and any kind 
+and Pedro Castillo, pedro (at) geneura.ugr.es. 
+
+Patient users that have submitted bugs include <a
+href='http://barbacana.net'>jamarier</a>, <a
+href='http://leandrohermida.com'>Leandro Hermida</a>, Jrme Qulin
+Mike Gajewski and Cristoph Meissner. <a href='http://alexm.org'>Alex
+Muntada</a>, from the <a href='http://barcelona.pm.org/'>Barcelona
+Perl Mongers</a>, helped me solve a problem with the Makefile.PL.
+
+Bug reports (and patches), requests and any kind 
 of comment are welcome.
 
 =end html
 
-=head1 Examples
-
-There are a few examples in the C<examples> subdirectory, which should
-have been included with your CPAN bundle. For instance, check out
-C<tide_float.pl>, an example of floating point vector optimization, or
-C<cd examples; run_easy_ga.pl p_peaks.yaml>, which should run an
-    example of a
-simple GA on the P_Peaks deceptive function.
-
-Some other examples are installed: check out L<tide_bitstring.pl>,
-    L<tide_float.pl> and L<canonical-genetic-algorithm.pl>, which you
-    can run and play with to get a taste of what EA programming is
-    like, and then ammend, add and modify at leisure to create your
-    own evolutionary algorithms. For a GUI example, check
-    L<rectangle-coverage.pl>, which uses L<Tk> to show the population
-    and its evolution.
-
 =head1 SEE ALSO
 
+If you are just looking for a plain vanilla genetic algorithm for
+didactic purposes, check also L<Algorithm::Evolutionary::Simple>,
+which does the job in a straight fashion and can be used easily for
+demos or adapting it to external fitness functions. 
+
 =over
 
 =item L<Algorithm::Evolutionary::Op::Base>.
@@ -215,7 +226,8 @@ Some other examples are installed: check out L<tide_bitstring.pl>,
 
 =item L<Algorithm::Evolutionary::Op::CanonicalGA>.
 
-=item L<XML> for an explanation of the XML format used.
+=item L<XML> for an explanation of the XML format used, although it's
+now rather obsolete. 
 
 =item L<POE::Component::Algorithm::Evolutionary> if you want to mix
 evolutionary algorithms with anything else easily.
@@ -236,9 +248,9 @@ L<AI::Genetic::Pro>.
 This file is released under the GPL. See the LICENSE file included in this distribution,
 or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.17 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2012/07/09 15:12:35 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.21 2012/07/09 15:12:35 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.17 $
+  $Revision: 3.21 $
 
 =cut
