@@ -1,6 +1,7 @@
 use strict; # -*- cperl -*-
 use warnings;
 
+use lib qw( ../../../../lib );
 
 =head1 NAME
 
@@ -26,7 +27,7 @@ use warnings;
 
 package Algorithm::Evolutionary::Fitness::Knapsack;
 
-our $VERSION = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp qw( croak );
 use base qw(Algorithm::Evolutionary::Fitness::String);
@@ -91,8 +92,8 @@ sub knapsack {
       my $this_bit=substr ($string, $i, 1);
       
       if ($this_bit == 1)  {
-        $profit = $profit + $profits[$i];
-        $weight = $weight + $weights[$i];
+        $profit += $profits[$i];
+        $weight += $weights[$i];
       }
     }
     
@@ -112,10 +113,10 @@ sub knapsack {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Knapsack.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2010/09/24 08:39:07 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Knapsack.pm,v 3.1 2010/09/24 08:39:07 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.1 $
   $Name $
 
 =cut
