@@ -1,6 +1,8 @@
 use strict;
 use warnings;
 
+use lib qw( ../../../../lib );
+
 =head1 NAME
 
     Algorithm::Evolutionary::Fitness::wP_Peaks - wP Peaks problem generator - weighted version of P_Peaks
@@ -12,12 +14,12 @@ use warnings;
     for (my $i = 0; $i < 99; $i ++ ) {
        push @weights, 0.99;
     }
-    my $p_peaks = Algorithm::Evolutionary::Fitness::P_Peaks->new( $number_of_bits, @weights ); #Number of peaks = scalar  @weights
+    my $wp_peaks = Algorithm::Evolutionary::Fitness::wP_Peaks->new( $number_of_bits, @weights ); #Number of peaks = scalar  @weights
 
     # Or use an alternative ctor
     my $descriptor = { number_of_peaks => 100,
                        weight => 0.99 };
-    my $p_peaks = Algorithm::Evolutionary::Fitness::P_Peaks->new( $number_of_bits, $descriptor)
+    my $wp_peaks = Algorithm::Evolutionary::Fitness::wP_Peaks->new( $number_of_bits, $descriptor)
 
 =head1 DESCRIPTION
 
@@ -29,7 +31,7 @@ use warnings;
 
 package Algorithm::Evolutionary::Fitness::wP_Peaks;
 
-our $VERSION = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ ) ;
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; 
 
 use String::Random;
 use Algorithm::Evolutionary::Utils qw(hamming);
@@ -63,7 +65,7 @@ sub new {
   my $generator = new String::Random;
   my @peaks;
   my $regex = "\[01\]{$bits}";
-  for my $s qw( bits generator regex ) {
+  for my $s ( qw( bits generator regex ) ) {
       eval "\$self->{'$s'} = \$$s";
   }
   while ( @weights ) {
@@ -120,10 +122,10 @@ sub p_peaks {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/wP_Peaks.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2012/07/08 16:37:25 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/wP_Peaks.pm,v 3.2 2012/07/08 16:37:25 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.2 $
   $Name $
 
 =cut
