@@ -3,7 +3,8 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Base - Base class for OPEAL operators; operators are any object with the "apply" method, which does things to individuals or populations.
+Algorithm::Evolutionary::Op::Base - Base class for Algorithm::Evolutionary operators, that is any object with the "apply" method, which does things to
+individuals or populations.
 
 =head1 SYNOPSIS
 
@@ -43,7 +44,8 @@ use B::Deparse; #For serializing code
 use Algorithm::Evolutionary::Utils qw(parse_xml);
 
 use Carp;
-our ($VERSION) = ( '$Revision: 2.5 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our %parameters;
 
 =head2 AUTOLOAD
 
@@ -85,6 +87,22 @@ sub new {
   return $self;
 }
 
+=head2 create( [@operator_parameters] )
+
+Creates an operator via its default parameters. Probably obsolete
+
+=cut
+
+sub create {
+  my $class = shift;
+  my $self;
+  for my $p ( keys %parameters ) {
+    $self->{"_$p"} = shift || $parameters{$p}; # Default
+  }
+  bless $self, $class;
+  return $self;
+}
+
 =head2 fromXML()
 
 Takes a definition in the shape <op></op> and turns it into an object, 
@@ -262,7 +280,10 @@ sub set {
   }
 }
 
-=head1 Known subclasses
+=head2 Known subclasses
+
+This is quite incomplete. Should be either generated automatically or
+suppressed altogether 
 
 =over 4
 
@@ -292,7 +313,7 @@ L<Algorithm::Evolutionary::Op::Novelty_Mutation>
 
 =item * 
 
-L<Algorithm::Evolutionary::Op::Crossover|Algorithm::Evolutionary::Op:Crossover>
+L<Algorithm::Evolutionary::Op:Crossover>
 
 =item * 
 
@@ -324,7 +345,8 @@ L<Algorithm::Evolutionary::Op::DeltaTerm|Algorithm::Evolutionary::Op::DeltaTerm>
 L<Algorithm::Evolutionary::Op::Easy|Algorithm::Evolutionary::Op::Easy>
 
 =item * 
-L<Algorithm::Evolutionary::Op::FullAlgorithm|Algorithm::Evolutionary::Op::FullAlgorithm>
+
+L<Algorithm::Evolutionary::Op::FullAlgorithm>
 
 
 
@@ -340,10 +362,10 @@ L<XML>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/09 10:05:06 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Base.pm,v 2.5 2009/02/09 10:05:06 jmerelo Exp $ 
+  CVS Info: $Date: 2009/09/14 16:36:38 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Base.pm,v 3.2 2009/09/14 16:36:38 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.5 $
+  $Revision: 3.2 $
   $Name $
 
 =cut
